.. _utils:

=====
Utils
=====

This is the documentation for util functions.

dataframe_functions
-------------------
.. autofunction:: sam.utils.sum_grouped_columns
.. autofunction:: sam.utils.has_strictly_increasing_index
.. autofunction:: sam.utils.contains_nans
.. autofunction:: sam.utils.assert_contains_nans

sklearn helpers
---------------
.. autoclass:: sam.utils.FunctionTransformerWithNames
    :members:
    :undoc-members:
    :show-inheritance:
